@@ -327,6 +327,7 @@ start_search_finished (GtkSourceSearchContext *search_context,
 							  result,
 							  &match_start,
 							  &match_end,
+							  NULL,
 							  NULL);
 
 	buffer = gtk_source_search_context_get_buffer (search_context);
@@ -390,6 +391,7 @@ forward_search_finished (GtkSourceSearchContext *search_context,
 							  result,
 							  &match_start,
 							  &match_end,
+							  NULL,
 							  NULL);
 
 	if (found)
@@ -447,6 +449,7 @@ backward_search_finished (GtkSourceSearchContext *search_context,
 							   result,
 							   &match_start,
 							   &match_end,
+							   NULL,
 							   NULL);
 
 	buffer = gtk_source_search_context_get_buffer (search_context);
@@ -849,11 +852,17 @@ search_entry_escaped (GtkSearchEntry *entry,
 	if (frame->search_mode == SEARCH &&
 	    search_context != NULL)
 	{
+		GtkSourceSearchContext *search_context;
+		GtkTextBuffer *buffer;
+
 		g_clear_object (&frame->search_settings);
 		frame->search_settings = copy_search_settings (frame->old_search_settings);
 
-		gtk_source_search_context_set_settings (search_context,
-		                                        frame->search_settings);
+		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
+		search_context = gtk_source_search_context_new (GTK_SOURCE_BUFFER (buffer),
+		                                                frame->search_settings);
+		gedit_document_set_search_context (GEDIT_DOCUMENT (buffer), search_context);
+		g_object_unref (search_context);
 
 		g_free (frame->search_text);
 		frame->search_text = NULL;
